package com.yanzhu.system.mapper;

import com.yanzhu.system.domain.flowable.FlowTaskEntity;

import java.util.List;
import java.util.Map;

/***
 * 工作流业务相关
 */
public interface FlowBusinessKeyMapper {

    /**
     * 根据条件查询所有流任务
     * @param flowTaskEntity
     * @return
     */
    public List<FlowTaskEntity> selectAllFlowTaskByParams(FlowTaskEntity flowTaskEntity);

    /**
     * 根据流程Id查询操作日志
     * @param procInsId
     * @return
     */
    public List<Map<String, Object>> selectCommentByProcInsId(String procInsId);

    /**
     * 根据流程Id查询表单数据
     * @param procInsId
     * @return
     */
    public List<Map<String, Object>> selectFormDatasByProcInsId(String procInsId);

    /**
     * 查询我的代办任务
     * @param flowTaskEntity
     * @return
     */
    public List<Map<String, Object>> selectMyAwaitFlowTask(FlowTaskEntity flowTaskEntity);

    /**
     * 查询我的已办任务
     * @param flowTaskEntity
     * @return
     */
    public List<Map<String, Object>> selectMyFinishedFlowTask(FlowTaskEntity flowTaskEntity);

}
